import type { Metadata } from "next";
import { Geist, Geist_Mono } from "next/font/google";

import "@/app/globals.css";
import { DeviceProvider } from "@/contexts/DeviceContext";
import { SessionProvider } from "@/contexts/SessionContext";
import I18nProvider from "@/providers/I18nProvider";

const geistSans = Geist({
  variable: "--font-geist-sans",
  subsets: ["latin"],
});

const geistMono = Geist_Mono({
  variable: "--font-geist-mono",
  subsets: ["latin"],
});

export const metadata: Metadata = {
  title: "Create Next App",
  description: "Generated by create next app",
};

export default function RootLayout({ children }: { children: React.ReactNode }) {
  return (
    <html lang="en">
      <body className={`bg-slate-100 dark:bg-slate-800`}>
        <SessionProvider>
          <DeviceProvider>
            <I18nProvider>{children}</I18nProvider>
          </DeviceProvider>
        </SessionProvider>
      </body>
    </html>
  );
}
